import { Request, Response } from "express";
import { client as bot } from "@bot/bot";
import prisma from "generated/prisma";
import { getLogger } from "@server/../log";

const logger = getLogger(__filename);

export const get = async (request: Request, response: Response) => {
    logger.debug("GET - filter page");

    const guildId = request.params.guildId;
    const guild = bot.guilds.cache.get(guildId);

    if (!guild) {
        response.status(404).send("404: guild not found");
        return;
    }

    const matchingAlgorithms: Record<keyof typeof prisma.MatchingAlgorithms, string> = {
        ANY: "Any Word",
        ALL: "All Words",
        EXACT: "Exact Match",
        REGEX: "Regular Expression",
        FUZZY: "Fuzzy Match"
    };

    response.render("guild/filters", {
        title: `${guild.name} - Relay`,
        guild: guild,
        matchingAlgorithms: matchingAlgorithms
    });
};

export default { get }